pub trait ArrowMessage {
// Required methods
fn field(name: impl Into<String>) -> Field;
fn try_into_arrow(self) -> Result<ArrayRef>;
fn try_from_arrow(data: ArrayData) -> Result<Self>
where Self: Sized;
}Expand description
Trait to represent a message that can be converted to and from an Arrow array.
Required Methods
Sourcefn field(name: impl Into<String>) -> Field
fn field(name: impl Into<String>) -> Field
Each message must declare how it’s represented as an Arrow field.
Sourcefn try_into_arrow(self) -> Result<ArrayRef>
fn try_into_arrow(self) -> Result<ArrayRef>
Try to convert the message into an Arrow array.
Sourcefn try_from_arrow(data: ArrayData) -> Result<Self>where
Self: Sized,
fn try_from_arrow(data: ArrayData) -> Result<Self>where
Self: Sized,
Try to convert an Arrow array into the message.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.